import pytest
from pydantic import BaseModel, ValidationError

from gso.products.product_blocks.site import LatitudeCoordinate, LongitudeCoordinate


class LatitudeModel(BaseModel):
    latitude: LatitudeCoordinate


class LongitudeModel(BaseModel):
    longitude: LongitudeCoordinate


@pytest.mark.parametrize(
    ("input_value", "is_valid"),
    [
        (40.7128, True),
        (-74.0060, True),
        (90, True),
        (-90, True),
        (0, True),
        (45.6, True),
        (91, False),
        (-91, False),
        (180, False),
        (-180, False),
        ("abc", False),
        (90.1, False),
    ],
)
def test_latitude(input_value, is_valid):
    if is_valid:
        assert LatitudeModel(latitude=input_value).latitude == input_value
    else:
        with pytest.raises(ValidationError):
            LatitudeModel(latitude=input_value)


@pytest.mark.parametrize(
    ("input_value", "is_valid"),
    [
        (40.7128, True),
        (-74.0060, True),
        (180, True),
        (-180, True),
        (0, True),
        (90.1, True),
        (181, False),
        (-181, False),
        (200, False),
        (-200, False),
        ("abc", False),
        ("90a", False),
    ],
)
def test_longitude(input_value, is_valid):
    if is_valid:
        assert LongitudeModel(longitude=input_value).longitude == input_value
    else:
        with pytest.raises(ValidationError):
            LongitudeModel(longitude=input_value)
